* `Bradley Ayers <bradley.ayers@gmail.com>`_
* `Dag Odenhall <dag.odenhall@gmail.com>`_
* `Daniel Neuhäuser <dasdasich@gmail.com>`_
* `Simon Sapin <simon.sapin@exyr.org>`_
* `Will Maier <willmaier@ml1.net>`_
* `Mounier Florian <paradoxxx.zero@gmail.com>`_
